Struct Layout

pub struct Layout<'a> { /* private fields */ }
The bounds of a Node and its children, using absolute coordinates.

Implementations



impl<'a> Layout<'a>

pub fn new(node: &'a Node) -> Layout<'a>

Creates a new Layout for the given Node at the origin.

pub fn with_offset(offset: Vector, node: &'a Node) -> Layout<'a>

Creates a new Layout for the given Node with the provided offset from the origin.

pub fn with_virtual_offset(self, virtual_offset: Vector) -> Layout<'a>

Returns a new layout with the virtual offset

pub fn position(&self) -> Point

Returns the position of the Layout.

pub fn virtual_offset(&self) -> Vector

The virtual offset of the layout. May represent the scroll positions in pixels of a scrollable, for example.

pub fn bounds(&self) -> Rectangle

Returns the bounds of the Layout.

The returned Rectangle describes the position and size of a Node.

pub fn children(self) -> impl DoubleEndedIterator + ExactSizeIterator

Returns an iterator over the children of this Layout.

pub fn child(self, index: usize) -> Layout<'a>

Returns the Layout of the child at the given index.

This can be useful if you ever need to access children out of order for layering purposes.

Panics

Panics if index is out of bounds.